@@ -327,6 +327,13 @@ class DobissTempSensor(DobissSensor):
             status = self.attributes["status"]
         return status
 
+    @property
+    def time(self):
+        time = None
+        if "time" in self.attributes:
+            time = self.attributes["time"]
+        return time
+
     @property
     def calendar(self):
         """Return the current preset mode, e.g., home, away, temp."""
